# File with a couple of standard sh-functions for use in i-Package
# phases

# ii2checksanity
# Check sanity of environment variables

ii2checksanity()
{
	if [ "${II2INSTALLDIR}" == "" ]
	then
		echo "### ${PROGNAME}: II2INSTALLDIR is empty. Bailing out..." >&2
		exit 1
	fi
	if [ "${II2PKGDIR}" == "" ]
	then
		echo "### ${PROGNAME}: II2PKGDIR is empty. Bailing out..." >&2
		exit 1
	fi
}

# ii2calledfrom()
# Report caller if this has been set through ${II2CALLEDFROM}

ii2calledfrom()
{
	if [ "${II2CALLEDFROM}" != "" ]
	then
		echo "### ${PROGNAME}: Called from ${II2CALLEDFROM}"
	fi
}

# ii2checksubdirs()
# - first argument: root directory (normally II2INSTALLDIR)
# - rest arguments: subdirs of root directory
# These are checked for existence and writability and warnings are produced

ii2checksubdirs()
{
	rootdir="$1"
	shift

	for subdir in $*
	do
		if [ ! -d "${rootdir}/${subdir}" ]
		then
			echo "### ${PROGNAME}: Cannot find ${rootdir}/${subdir}"
			echo "### ${PROGNAME}: This is normally no cause for alarm as this is true on initial installs, when uninstall is run more than once, or when the i-Package contents have changed layout over time."
		elif [ ! -w "${rootdir}/${subdir}" ]
		then
			echo "### ${PROGNAME}: Cannot write in ${rootdir}/${subdir}. Bailing out..." 2>&1
			exit 1
		fi
	done
}

# ii2removeemptysubdirs
# Remove named empty subdirs of rootdir (normally II2INSTALDIR)

ii2removeemptysubdirs()
{
	rootdir="$1"
	shift

	for subdir in $*
	do
		echo "### ${PROGNAME}: Removing ${rootdir}/${subdir} (if empty)"
		rmdir -p "$rootdir/$subdir"
	done
}

# ii2removeaccordingtolistfile
# Take the list file, use it to clean up in the remove script

ii2removeaccordingtolistfile()
{
    pkgdir="${II2PKGDIR}"
    installdir="${II2INSTALLDIR}"
    pkgname=`basename $pkgdir .ii2`

    listfile="$pkgdir/$pkgname.l.bz2"
    if [ -f $listfile ]
    then
	/usr/bin/bzcat "$listfile"|uniq|sort -r|(cd $installdir; xargs -t -L 50 rm -f)
	(/usr/bin/bzcat "$listfile"|uniq|sort -r|xargs -L 1 dirname)|sort -r|uniq|(cd $installdir; xargs -t -L 50 rmdir -p)
    else
	echo "Listfile cannot be opened. Cannot use automated remove!\n" 
    fi

    listfile="$pkgdir/$pkgname-oldversions.l.bz2"
    if [ -f $listfile ]
    then
	echo "Removing any known leftovers from previous versions..."
	/usr/bin/bzcat "$listfile"|uniq|sort -r|(cd $installdir; xargs -t -L 50 rm -f)
	(/usr/bin/bzcat "$listfile"|uniq|sort -r|xargs -L 1 dirname)|sort -r|uniq|(cd $installdir; xargs -t -L 50 rmdir -p)
    fi
}



# ii2runprog
# Run another prog after an informational message

ii2runprog()
{
    myname="$0"
    echo "### ${myname}: running $1"
    (export II2CALLEDFROM="$myname"; "$1")
}

# ii2runphase
# Run another phase of this i-Package
# Phase should be remove, selector, configure or prepare and it should of course exist

ii2runphase()
{
	phasename="$1"
	pkgname=`${II2RESOURCES}/basename "${II2PKGDIR}" .ii2`
	phasename="${II2PKGDIR}/${pkgname}.${phasename}"
	ii2runprog "${phasename}"
}

# ii2repairX11
# Leopard and pre-Leopard use different X11 locations. Stuff compiled against X11 on Leopard
# does not run on pre-Leopard, unless /usr/X11 links to an X11 install 

ii2fixPreLeopardX11()
{
    if [ ! -e /usr/X11 ]
    then
	# Pre-Leopard or Leopard without X11 installed
	darwinmainversion=`/usr/bin/uname -r|/usr/bin/sed 's/\..*//'`
	if [ -e /usr/X11R6 -a "${darwinmainversion}" -lt "9" ]
	then
	    # Pre-Leopard (or Leopard without X11) without X11R6 symlink 
	    echo "### Fixing pre-Leopard X11 to work with Leopard-compiled programs"
	    echo "### If this is Leopard, no X11 is installed and the fix should be harmless"
	    ln -s /usr/X11R6 /usr/X11
	fi
    fi
}

true

# $Id$
